#[non_exhaustive]pub struct CreateCoreDefinitionInput {
pub amzn_client_token: Option<String>,
pub initial_version: Option<CoreDefinitionVersion>,
pub name: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Information needed to create a core definition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.amzn_client_token: Option<String>A client token used to correlate requests and responses.
initial_version: Option<CoreDefinitionVersion>Information about the initial version of the core definition.
name: Option<String>The name of the core definition.
Tag(s) to add to the new resource.
Implementations
Sourceimpl CreateCoreDefinitionInput
impl CreateCoreDefinitionInput
Sourcepub fn amzn_client_token(&self) -> Option<&str>
pub fn amzn_client_token(&self) -> Option<&str>
A client token used to correlate requests and responses.
Sourcepub fn initial_version(&self) -> Option<&CoreDefinitionVersion>
pub fn initial_version(&self) -> Option<&CoreDefinitionVersion>
Information about the initial version of the core definition.
Tag(s) to add to the new resource.
Sourceimpl CreateCoreDefinitionInput
impl CreateCoreDefinitionInput
Sourcepub fn builder() -> CreateCoreDefinitionInputBuilder
pub fn builder() -> CreateCoreDefinitionInputBuilder
Creates a new builder-style object to manufacture CreateCoreDefinitionInput.